@@ -14,7 +14,14 @@ class FileType(Enum):
     SWIFT = 8
     TERRAFORM = 9
     YAML = 10
-    OTHER = 11
+    C_SHARP = 11
+    C = 12
+    C_PLUS_PLUS = 13
+    CONFIG = 14
+    INI = 15
+    PROPERTIES = 16
+    TOML = 17
+    OTHER = 18
 
 
 def determine_file_type(filename: str) -> FileType:
@@ -34,4 +41,14 @@ def determine_file_type(filename: str) -> FileType:
         '.tf': FileType.TERRAFORM,
         '.yaml': FileType.YAML,
         '.yml': FileType.YAML,
+        '.cs': FileType.C_SHARP,
+        '.c': FileType.C,
+        '.cpp': FileType.C_PLUS_PLUS,
+        '.cnf': FileType.CONFIG,
+        '.conf': FileType.CONFIG,
+        '.cfg': FileType.CONFIG,
+        '.cf': FileType.CONFIG,
+        '.ini': FileType.INI,
+        '.properties': FileType.PROPERTIES,
+        '.toml': FileType.TOML
     }.get(file_extension, FileType.OTHER)
